#
# spec file for package UEFITool
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           UEFITool
Version:        20201122
Release:        1.16
Summary:        Tools to inspect and work on UEFI BIOSes
License:        BSD-2-Clause
Group:          Development/Tools/Other
URL:            https://github.com/LongSoft/UEFITool
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)

%description
UEFITool is a C++/Qt program for parsing, extracting and
modifying UEFI firmware images. It supports parsing of full BIOS images
starting with the flash descriptor or any binary files containing UEFI
volumes.

%prep
%setup -q

%build
%qmake5
%make_jobs
for i in UEFIPatch UEFIReplace; do
  pushd $i
    %qmake5
    %make_build
  popd
done

%install
install -Dpm 0755 UEFITool \
  %{buildroot}/%{_bindir}/UEFITool
for i in UEFIPatch UEFIReplace; do
  pushd $i
    install -Dpm 0755 $i %{buildroot}/%{_bindir}/$i
  popd
done

%files
%license LICENSE.md
%doc README.rst
%{_bindir}/UEFITool
%{_bindir}/UEFIPatch
%{_bindir}/UEFIReplace

%changelog
* Tue Nov 24 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20201122:
  * Switch CI to GitHub Actions
  * Drop AppVeyor
  * Version bump
  * Revert "Update CI configuration to dpl v2"
  * Update CI configuration to dpl v2
  * Fix mishandling trailing newline
  * Fix compatibility with older UEFIPatch
  * Added MSR patches for C422, C620 motherboards (#204)
  * Add support to parse/reconstruct LZMAF86 sections (#198)
* Wed Jan 22 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20200120:
  * Add 'Do not rebuild' support for volumes
  * Version bump
* Fri Dec 20 2019 mpluskal@suse.com
- Update to version 20191103:
  * Fix C++03 compatibility
  * Backport rebuild logic
  * Support applying patches from terminal, closes #186
* Wed Oct 23 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20181230:
  * Implement custom LZMA dictionary size support, fixes #154
* Fri Dec 14 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 20180624:
  * Unify version scheme
  * Support replacing raw sections and ffs via -asis
  * Allow subguid matching for UEFIReplace
  * Fix recursion in UEFIReplace
  * Add -o / --output flag to UEFIPatch
  * Implement replace all and add -o (--output) path to UEFIReplace
  * Backport decompression updates from new_engine
  * Add misc patches unrelated to Intel PowerManagement
  * Implement external patches.txt path for UEFIPatch
  * Fix Intel descriptor version parsing at reading
  * Properly read Intel descriptor version, thx @platomav
  * Recognise B360MHD3.F3 descriptor version
  * Remove legacy UEFIFind and UEFIExtract in favour of new_engine branch
  * Fix EC region parse
* Thu Mar  8 2018 mpluskal@suse.com
- Update to version 20180225:
  * fixed rebase PEI files with nonstandard alignment
  * Fixed patches for Skylake-X
  * multiple fixes
  * fix for #99
  * 0.22.1 multiple FFSv3 support fixes, thanks to @osresearch
  * add FFSv3 support with large files and large sections
* Mon Jul 24 2017 mpluskal@suse.com
- Update to version 20170506:
  * Add UEFIReplace.
* Sat Mar  4 2017 jengelh@inai.de
- Trim description to relevant parts
* Sun Feb 26 2017 mpluskal@suse.com
- Update to version 20170212:
  * Corrected EC region placement
  * Corrected #34
  * UT 0.21.2
  * UT 0.21.3 / UP 0.3.7
  * Fix a compiler warning
  * UT 0.21.4 / UP 0.3.8
  * UT 0.21.5 /UP 0.3.9 untested
  * Forgot to bump UP version
  * Update patches.txt
  * Add Kaby Lake support.
- Add _service
- Cleanup spec file
* Sat Jan 10 2015 johannesobermayr@gmx.de
- Initial package
